==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebExpansionPanelDescriptionMetadata_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExpansionPanelDescription } from "./WebExpansionPanelDescription";
import { WebExpansionPanelComponentEventArgsDescription } from "./WebExpansionPanelComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebExpansionPanelDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebExpansionPanelDescriptionMetadata extends Base {
        static b(a) {
            if (WebExpansionPanelDescriptionMetadata.a == null) {
                WebExpansionPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebExpansionPanelDescriptionMetadata.c(WebExpansionPanelDescriptionMetadata.a);
            }
            if (a.k(WebExpansionPanelDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebExpansionPanelDescriptionMetadata.a);
            WebExpansionPanelComponentEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ExpansionPanel");
            a.item("__tagNameWC", "String:igc-expansion-panel");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Open", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("IndicatorPosition", "ExportedType:string:ExpansionPanelIndicatorPosition");
            a.item("IndicatorPosition@stringUnion", "WebComponents;React");
            a.item("IndicatorPosition@names", "None;Start;End");
            a.item("OpeningRef", "EventRef::opening");
            a.item("OpenedRef", "EventRef::opened");
            a.item("ClosingRef", "EventRef::closing");
            a.item("ClosedRef", "EventRef::closed");
        }
        static d(a) {
            WebExpansionPanelDescriptionMetadata.b(a);
            a.ad("WebExpansionPanel", () => new WebExpansionPanelDescription());
            a.ac("WebExpansionPanel", WebExpansionPanelDescriptionMetadata.a);
        }
    }
    WebExpansionPanelDescriptionMetadata.$t = markType(WebExpansionPanelDescriptionMetadata, 'WebExpansionPanelDescriptionMetadata');
    WebExpansionPanelDescriptionMetadata.a = null;
    return WebExpansionPanelDescriptionMetadata;
})();
/**
 * @hidden
 */
export let WebExpansionPanelComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebExpansionPanelComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebExpansionPanelComponentEventArgsDescriptionMetadata.a == null) {
                WebExpansionPanelComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebExpansionPanelComponentEventArgsDescriptionMetadata.c(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebExpansionPanelComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
            WebExpansionPanelDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ExpansionPanelComponentEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebExpansionPanel");
        }
        static d(a) {
            WebExpansionPanelComponentEventArgsDescriptionMetadata.b(a);
            a.ad("WebExpansionPanelComponentEventArgs", () => new WebExpansionPanelComponentEventArgsDescription());
            a.ac("WebExpansionPanelComponentEventArgs", WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebExpansionPanelComponentEventArgsDescriptionMetadata.$t = markType(WebExpansionPanelComponentEventArgsDescriptionMetadata, 'WebExpansionPanelComponentEventArgsDescriptionMetadata');
    WebExpansionPanelComponentEventArgsDescriptionMetadata.a = null;
    return WebExpansionPanelComponentEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebExpansionPanelDescriptionMetadata_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExpansionPanelDescription } from "./WebExpansionPanelDescription";
import { WebExpansionPanelComponentEventArgsDescription } from "./WebExpansionPanelComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebExpansionPanelDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebExpansionPanelDescriptionMetadata extends Base {
        static b(a) {
            if (WebExpansionPanelDescriptionMetadata.a == null) {
                WebExpansionPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebExpansionPanelDescriptionMetadata.c(WebExpansionPanelDescriptionMetadata.a);
            }
            if (a.k(WebExpansionPanelDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebExpansionPanelDescriptionMetadata.a);
            WebExpansionPanelComponentEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ExpansionPanel");
            a.item("__tagNameWC", "String:igc-expansion-panel");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Open", "Boolean");
            a.item("Disabled", "Boolean");
            a.item("IndicatorPosition", "ExportedType:string:ExpansionPanelIndicatorPosition");
            a.item("IndicatorPosition@stringUnion", "WebComponents;React");
            a.item("IndicatorPosition@names", "Start;End;None");
            a.item("OpeningRef", "EventRef::opening");
            a.item("OpenedRef", "EventRef::opened");
            a.item("ClosingRef", "EventRef::closing");
            a.item("ClosedRef", "EventRef::closed");
        }
        static d(a) {
            WebExpansionPanelDescriptionMetadata.b(a);
            a.ae("WebExpansionPanel", () => new WebExpansionPanelDescription());
            a.ad("WebExpansionPanel", WebExpansionPanelDescriptionMetadata.a);
        }
    }
    WebExpansionPanelDescriptionMetadata.$t = markType(WebExpansionPanelDescriptionMetadata, 'WebExpansionPanelDescriptionMetadata');
    WebExpansionPanelDescriptionMetadata.a = null;
    return WebExpansionPanelDescriptionMetadata;
})();
/**
 * @hidden
 */
export let WebExpansionPanelComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebExpansionPanelComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebExpansionPanelComponentEventArgsDescriptionMetadata.a == null) {
                WebExpansionPanelComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebExpansionPanelComponentEventArgsDescriptionMetadata.c(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebExpansionPanelComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
            WebExpansionPanelDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ExpansionPanelComponentEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebExpansionPanel");
        }
        static d(a) {
            WebExpansionPanelComponentEventArgsDescriptionMetadata.b(a);
            a.ae("WebExpansionPanelComponentEventArgs", () => new WebExpansionPanelComponentEventArgsDescription());
            a.ad("WebExpansionPanelComponentEventArgs", WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebExpansionPanelComponentEventArgsDescriptionMetadata.$t = markType(WebExpansionPanelComponentEventArgsDescriptionMetadata, 'WebExpansionPanelComponentEventArgsDescriptionMetadata');
    WebExpansionPanelComponentEventArgsDescriptionMetadata.a = null;
    return WebExpansionPanelComponentEventArgsDescriptionMetadata;
})();
